pub struct ShipmentDetail {Show 14 fields
pub warehouse_id: Option<String>,
pub amazon_order_id: Option<String>,
pub amazon_shipment_id: Option<String>,
pub purchase_date: Option<String>,
pub shipping_address: Option<Box<Address>>,
pub payment_method_details: Option<Vec<String>>,
pub marketplace_id: Option<String>,
pub seller_id: Option<String>,
pub buyer_name: Option<String>,
pub buyer_county: Option<String>,
pub buyer_tax_info: Option<Box<BuyerTaxInfo>>,
pub marketplace_tax_info: Option<Box<MarketplaceTaxInfo>>,
pub seller_display_name: Option<String>,
pub shipment_items: Option<Vec<ShipmentItem>>,
}Expand description
ShipmentDetail : The information required by a selling partner to issue a shipment invoice.
Fields
warehouse_id: Option<String>The Amazon-defined identifier for the warehouse.
amazon_order_id: Option<String>The Amazon-defined identifier for the order.
amazon_shipment_id: Option<String>The Amazon-defined identifier for the shipment.
purchase_date: Option<String>The date and time when the order was created.
shipping_address: Option<Box<Address>>payment_method_details: Option<Vec<String>>The list of payment method details.
marketplace_id: Option<String>The identifier for the marketplace where the order was placed.
seller_id: Option<String>The seller identifier.
buyer_name: Option<String>The name of the buyer.
buyer_county: Option<String>The county of the buyer.
buyer_tax_info: Option<Box<BuyerTaxInfo>>marketplace_tax_info: Option<Box<MarketplaceTaxInfo>>seller_display_name: Option<String>The seller’s friendly name registered in the marketplace.
shipment_items: Option<Vec<ShipmentItem>>A list of shipment items.
Implementations
sourceimpl ShipmentDetail
impl ShipmentDetail
sourcepub fn new() -> ShipmentDetail
pub fn new() -> ShipmentDetail
The information required by a selling partner to issue a shipment invoice.